@@ -5,6 +5,10 @@ from pydantic import BaseModel, Field, validator
 
 
 class User(BaseModel):
+    """
+    https://core.telegram.org/bots/api#user
+    This object represents a Telegram user or bot.
+    """
     id: int
     is_bot: bool
     first_name: str
@@ -17,6 +21,10 @@ class User(BaseModel):
 
 
 class ChatPhoto(BaseModel):
+    """
+    https://core.telegram.org/bots/api#chatphoto
+    This object represents a chat photo.
+    """
     small_file_id: str
     small_file_unique_id: str
     big_file_id: str
@@ -24,6 +32,10 @@ class ChatPhoto(BaseModel):
 
 
 class ChatPermissions(BaseModel):
+    """
+    https://core.telegram.org/bots/api#chatpermissions
+    Describes actions that a non-administrator user is allowed to take in a chat.
+    """
     can_send_messages: Optional[bool] = None
     can_send_media_messages: Optional[bool] = None
     can_send_polls: Optional[bool] = None
@@ -35,6 +47,10 @@ class ChatPermissions(BaseModel):
 
 
 class Location(BaseModel):
+    """
+    https://core.telegram.org/bots/api#location
+    This object represents a point on the map.
+    """
     longitude: float
     latitude: float
     horizontal_accuracy: Optional[float] = None
@@ -43,17 +59,25 @@ class Location(BaseModel):
     proximity_alert_radius: Optional[int] = None
 
     @validator('horizontal_accuracy')
-    def size_horizontal_accuracy_must_contain_a_range(self, value):
-        if value < 0 or value > 1500:
+    def size_horizontal_accuracy_must_contain_a_range(cls, v):
+        if v < 0 or v > 1500:
             raise ValueError('Must contain a range of 0 - 1500')
 
 
 class ChatLocation(BaseModel):
+    """
+    https://core.telegram.org/bots/api#chatlocation
+    Represents a location to which a chat is connected.
+    """
     location: Location
     address: str
 
 
 class Chat(BaseModel):
+    """
+    https://core.telegram.org/bots/api#chat
+    This object represents a chat.
+    """
     id: int
     type: str
     title: Optional[str] = None
@@ -75,6 +99,10 @@ class Chat(BaseModel):
 
 
 class MessageEntity(BaseModel):
+    """
+    https://core.telegram.org/bots/api#messageentity
+    This object represents one special entity in a text message. For example, hashtags, usernames, URLs, etc.
+    """
     type: str
     offset: int
     length: int
@@ -84,6 +112,10 @@ class MessageEntity(BaseModel):
 
 
 class PhotoSize(BaseModel):
+    """
+    https://core.telegram.org/bots/api#photosize
+    This object represents one size of a photo or a file / sticker thumbnail.
+    """
     file_id: str
     file_unique_id: str
     width: int
@@ -92,6 +124,10 @@ class PhotoSize(BaseModel):
 
 
 class Animation(BaseModel):
+    """
+    https://core.telegram.org/bots/api#animation
+    This object represents an animation file (GIF or H.264/MPEG-4 AVC video without sound).
+    """
     file_id: str
     file_unique_id: str
     width: int
@@ -104,6 +140,10 @@ class Animation(BaseModel):
 
 
 class Audio(BaseModel):
+    """
+    https://core.telegram.org/bots/api#audio
+    This object represents an audio file to be treated as music by the Telegram clients.
+    """
     file_id: str
     file_unique_id: str
     duration: int
@@ -116,6 +156,10 @@ class Audio(BaseModel):
 
 
 class Document(BaseModel):
+    """
+    https://core.telegram.org/bots/api#document
+    This object represents a general file (as opposed to photos, voice messages and audio files).
+    """
     file_id: str
     file_unique_id: str
     thumb: Optional[PhotoSize] = None
@@ -125,6 +169,10 @@ class Document(BaseModel):
 
 
 class Sticker(BaseModel):
+    """
+    https://core.telegram.org/bots/api#sticker
+    This object represents a sticker.
+    """
     file_id: str
     file_unique_id: str
     width: int
@@ -138,6 +186,10 @@ class Sticker(BaseModel):
 
 
 class Video(BaseModel):
+    """
+    https://core.telegram.org/bots/api#video
+    This object represents a video file.
+    """
     file_id: str
     file_unique_id: str
     width: int
@@ -150,6 +202,10 @@ class Video(BaseModel):
 
 
 class VideoNote(BaseModel):
+    """
+    https://core.telegram.org/bots/api#videonote
+    This object represents a video message (available in Telegram apps as of v.4.0).
+    """
     file_id: str
     file_unique_id: str
     length: int
@@ -159,6 +215,10 @@ class VideoNote(BaseModel):
 
 
 class Voice(BaseModel):
+    """
+    https://core.telegram.org/bots/api#voice
+    This object represents a voice note.
+    """
     file_id: str
     file_unique_id: str
     duration: int
@@ -167,6 +227,10 @@ class Voice(BaseModel):
 
 
 class Contact(BaseModel):
+    """
+    https://core.telegram.org/bots/api#contact
+    This object represents a phone contact.
+    """
     phone_number: str
     first_name: str
     last_name: Optional[str] = None
@@ -175,11 +239,19 @@ class Contact(BaseModel):
 
 
 class Dice(BaseModel):
+    """
+    https://core.telegram.org/bots/api#dice
+    This object represents an animated emoji that displays a random value.
+    """
     emoji: str
     value: int
 
 
 class Game(BaseModel):
+    """
+    https://core.telegram.org/bots/api#game
+    This object represents a game. Use BotFather to create and edit games, their short names will act as unique identifiers.
+    """
     title: str
     description: str
     photo: Union[list, PhotoSize, None] = None
@@ -189,11 +261,19 @@ class Game(BaseModel):
 
 
 class PollOption(BaseModel):
+    """
+    https://core.telegram.org/bots/api#polloption
+    This object contains information about one answer option in a poll.
+    """
     text: str
     voter_count: int
 
 
 class Poll(BaseModel):
+    """
+    https://core.telegram.org/bots/api#poll
+    This object contains information about a poll.
+    """
     id: str
     question: str
     options: Union[list, PollOption, None] = None
@@ -209,16 +289,24 @@ class Poll(BaseModel):
     close_date: Optional[int] = None
 
     @validator('question')
-    def question_characters_limit(self, value):
-        if len(value) > 300:
+    def question_characters_limit(cls, v):
+        if len(v) > 300:
             raise ValueError('question limited 300 characters')
 
 
 class MessageAutoDeleteTimerChanged(BaseModel):
+    """
+    https://core.telegram.org/bots/api#messageautodeletetimerchanged
+    This object represents a service message about a change in auto-delete timer settings.
+    """
     message_auto_delete_time: int
 
 
 class Venue(BaseModel):
+    """
+    https://core.telegram.org/bots/api#venue
+    This object represents a venue.
+    """
     location: Location
     title: str
     address: str
@@ -229,6 +317,10 @@ class Venue(BaseModel):
 
 
 class Invoice(BaseModel):
+    """
+    https://core.telegram.org/bots/api#invoice
+    This object contains basic information about an invoice.
+    """
     title: str
     description: str
     start_parameter: str
@@ -237,6 +329,10 @@ class Invoice(BaseModel):
 
 
 class ShippingAddress(BaseModel):
+    """
+    https://core.telegram.org/bots/api#shippingaddress
+    This object represents a shipping address.
+    """
     country_code: str
     state: str
     city: str
@@ -246,6 +342,10 @@ class ShippingAddress(BaseModel):
 
 
 class OrderInfo(BaseModel):
+    """
+    https://core.telegram.org/bots/api#orderinfo
+    This object represents information about an order.
+    """
     name: Optional[str] = None
     phone_number: Optional[str] = None
     email: Optional[str] = None
@@ -253,6 +353,10 @@ class OrderInfo(BaseModel):
 
 
 class SuccessfulPayment(BaseModel):
+    """
+    https://core.telegram.org/bots/api#successfulpayment
+    This object contains basic information about a successful payment.
+    """
     currency: str
     total_amount: int
     invoice_payload: str
@@ -263,6 +367,11 @@ class SuccessfulPayment(BaseModel):
 
 
 class PassportFile(BaseModel):
+    """
+    https://core.telegram.org/bots/api#passportfile
+    This object represents a file uploaded to Telegram Passport.
+     Currently all Telegram Passport files are in JPEG format when decrypted and don't exceed 10MB.
+    """
     file_id: str
     file_unique_id: str
     file_size: int
@@ -270,6 +379,10 @@ class PassportFile(BaseModel):
 
 
 class EncryptedPassportElement(BaseModel):
+    """
+    https://core.telegram.org/bots/api#encryptedpassportelement
+    Contains information about documents or other Telegram Passport elements shared with the bot by the user.
+    """
     type: str
     data: Optional[str] = None
     phone_number: Optional[str] = None
@@ -283,39 +396,75 @@ class EncryptedPassportElement(BaseModel):
 
 
 class EncryptedCredentials(BaseModel):
+    """
+    https://core.telegram.org/bots/api#encryptedcredentials
+    Contains data required for decrypting and authenticating EncryptedPassportElement.
+    See the Telegram Passport Documentation for a complete description of the data decryption and authentication processes.
+    """
     data: str
     hash: str
     secret: str
 
 
 class PassportData(BaseModel):
+    """
+    https://core.telegram.org/bots/api#passportdata
+    Contains information about Telegram Passport data shared with the bot by the user.
+    """
     data: Union[list, EncryptedPassportElement]
     credentials: EncryptedCredentials
 
 
 class ProximityAlertTriggered(BaseModel):
+    """
+    https://core.telegram.org/bots/api#proximityalerttriggered
+    This object represents the content of a service message, sent whenever a user in the chat triggers a proximity alert set by another user.
+    """
     traveler: User
     watcher: User
     distance: int
 
 
 class VoiceChatScheduled(BaseModel):
+    """
+    https://core.telegram.org/bots/api#voicechatscheduled
+    This object represents the content of a service message,
+    sent whenever a user in the chat triggers a proximity alert set by another user.
+    """
     start_date: int
 
 
 class VoiceChatStarted(BaseModel):
+    """
+    https://core.telegram.org/bots/api#voicechatstarted
+    This object represents a service message about a voice chat started in the chat. Currently holds no information.
+    """
     pass
 
 
 class VoiceChatEnded(BaseModel):
+    """
+    https://core.telegram.org/bots/api#voicechatended
+    This object represents a service message about a voice chat ended in the chat.
+    """
     duration: int
 
 
 class VoiceChatParticipantsInvited(BaseModel):
+    """
+    https://core.telegram.org/bots/api#voicechatparticipantsinvited
+    This object represents a service message about new members invited to a voice chat.
+    """
     users: Union[list, User, None] = None
 
 
 class LoginUrl(BaseModel):
+    """
+    https://core.telegram.org/bots/api#loginurl
+    This object represents a parameter of the inline keyboard button used to automatically authorize a user.
+    Serves as a great replacement for the Telegram Login Widget when the user is coming from Telegram.
+    All the user needs to do is tap/click a button and confirm that they want to log in.
+    """
     url: str
     forward_text: Optional[str] = None
     bot_username: Optional[str] = None
@@ -323,10 +472,18 @@ class LoginUrl(BaseModel):
 
 
 class CallbackGame(BaseModel):
+    """
+    https://core.telegram.org/bots/api#callbackgame
+    A placeholder, currently holds no information. Use BotFather to set up your game.
+    """
     pass
 
 
 class InlineKeyboardButton(BaseModel):
+    """
+    https://core.telegram.org/bots/api#inlinekeyboardbutton
+    This object represents one button of an inline keyboard. You must use exactly one of the optional fields.
+    """
     text: str
     url: Optional[str]
     login_url: Optional[LoginUrl] = None
@@ -338,10 +495,18 @@ class InlineKeyboardButton(BaseModel):
 
 
 class InlineKeyboardMarkup(BaseModel):
+    """
+    https://core.telegram.org/bots/api#inlinekeyboardmarkup
+    This object represents an inline keyboard that appears right next to the message it belongs to.
+    """
     inline_keyboard: Union[list, List[InlineKeyboardButton]]
 
 
 class Message(BaseModel):
+    """
+    https://core.telegram.org/bots/api#message
+    This object represents a message.
+    """
     message_id: int
     from_user: Optional[User] = Field(None, alias='from')
     sender_chat: Optional[Chat] = None
@@ -376,10 +541,10 @@ class Message(BaseModel):
     poll: Optional[Poll] = None
     venue: Optional[Venue] = None
     location: Optional[Location] = None
-    new_chat_members: Optional[list, User, None] = None
+    new_chat_members: Union[list, User, None] = None
     left_chat_member: Optional[User] = None
     new_chat_title: Optional[str] = None
-    new_chat_photo: Optional[list, PhotoSize, None] = None
+    new_chat_photo: Union[list, PhotoSize, None] = None
     delete_chat_photo: Optional[bool] = None
     group_chat_created: Optional[bool] = None
     supergroup_chat_created: Optional[bool] = None
@@ -401,6 +566,11 @@ class Message(BaseModel):
 
 
 class InlineQuery(BaseModel):
+    """
+    https://core.telegram.org/bots/api#inlinequery
+    This object represents an incoming inline query.
+     When the user sends an empty query, your bot could return some default or trending results.
+    """
     id: str
     from_user: User = Field(alias='from')
     query: str
@@ -409,12 +579,16 @@ class InlineQuery(BaseModel):
     location: Optional[Location] = None
 
     @validator('query')
-    def query_characters_limit(self, value):
-        if len(value) > 256:
+    def query_characters_limit(cls, v):
+        if len(v) > 256:
             raise ValueError('query limited 256 characters')
 
 
 class ChosenInlineResult(BaseModel):
+    """
+    https://core.telegram.org/bots/api#choseninlineresult
+    Represents a result of an inline query that was chosen by the user and sent to their chat partner.
+    """
     result_id: str
     from_user: User = Field(alias='from')
     location: Optional[Location] = None
@@ -423,6 +597,13 @@ class ChosenInlineResult(BaseModel):
 
 
 class CallbackQuery(BaseModel):
+    """
+    https://core.telegram.org/bots/api#callbackquery
+    This object represents an incoming callback query from a callback button in an inline keyboard.
+    If the button that originated the query was attached to a message sent by the bot, the field message will be present.
+    If the button was attached to a message sent via the bot (in inline mode), the field inline_message_id will be present.
+    Exactly one of the fields data or game_short_name will be present.
+    """
     id: str
     from_user: User = Field(alias='from')
     message: Optional[Message] = None
@@ -433,6 +614,10 @@ class CallbackQuery(BaseModel):
 
 
 class ShippingQuery(BaseModel):
+    """
+    https://core.telegram.org/bots/api#shippingquery
+    This object contains information about an incoming shipping query.
+    """
     id: str
     from_user: User = Field(alias='from')
     invoice_payload: str
@@ -440,6 +625,10 @@ class ShippingQuery(BaseModel):
 
 
 class PreCheckoutQuery(BaseModel):
+    """
+    https://core.telegram.org/bots/api#precheckoutquery
+    This object contains information about an incoming pre-checkout query.
+    """
     id: str
     from_user: User = Field(alias='from')
     currency: str
@@ -450,12 +639,20 @@ class PreCheckoutQuery(BaseModel):
 
 
 class PollAnswer(BaseModel):
+    """
+    https://core.telegram.org/bots/api#pollanswer
+    This object represents an answer of a user in a non-anonymous poll.
+    """
     poll_id: str
     user: User
     option_ids: Union[list, int]
 
 
 class ChatMemberOwner(BaseModel):
+    """
+    https://core.telegram.org/bots/api#chatmemberowner
+    Represents a chat member that owns the chat and has all administrator privileges.
+    """
     status: str
     user: User
     is_anonymous: bool
@@ -463,6 +660,10 @@ class ChatMemberOwner(BaseModel):
 
 
 class ChatMemberAdministrator(BaseModel):
+    """
+    https://core.telegram.org/bots/api#chatmemberadministrator
+    Represents a chat member that has some additional privileges.
+    """
     status: str
     user: User
     can_be_edited: bool
@@ -481,11 +682,19 @@ class ChatMemberAdministrator(BaseModel):
 
 
 class ChatMemberMember(BaseModel):
+    """
+    https://core.telegram.org/bots/api#chatmembermember
+    Represents a chat member that has no additional privileges or restrictions.
+    """
     status: str
     user: User
 
 
 class ChatMemberRestricted(BaseModel):
+    """
+    https://core.telegram.org/bots/api#chatmemberrestricted
+    Represents a chat member that is under certain restrictions in the chat. Supergroups only.
+    """
     status: str
     user: User
     is_member: bool
@@ -501,17 +710,29 @@ class ChatMemberRestricted(BaseModel):
 
 
 class ChatMemberLeft(BaseModel):
+    """
+    https://core.telegram.org/bots/api#chatmemberleft
+    Represents a chat member that isn't currently a member of the chat, but may join it themselves.
+    """
     status: str
     user: User
 
 
 class ChatMemberBanned(BaseModel):
+    """
+    https://core.telegram.org/bots/api#chatmemberbanned
+    Represents a chat member that was banned in the chat and can't return to the chat or view chat messages.
+    """
     status: str
     user: User
     until_date: int
 
 
 class ChatInviteLink(BaseModel):
+    """
+    https://core.telegram.org/bots/api#chatinvitelink
+    Represents an invite link for a chat.
+    """
     invite_link: str
     creator: User
     is_primary: bool
@@ -521,6 +742,10 @@ class ChatInviteLink(BaseModel):
 
 
 class ChatMemberUpdated(BaseModel):
+    """
+    https://core.telegram.org/bots/api#chatmemberupdated
+    This object represents changes in the status of a chat member.
+    """
     chat: Chat
     from_user: User = Field(alias='from')
     date: datetime
@@ -534,6 +759,11 @@ class ChatMemberUpdated(BaseModel):
 
 
 class Update(BaseModel):
+    """
+    https://core.telegram.org/bots/api#update
+    This object represents an incoming update.
+At most one of the optional parameters can be present in any given update.
+    """
     update_id: int
     message: Optional[Message] = None
     edited_message: Optional[Message] = None
